======================================================
``psyclone.psyir.nodes.array_of_structures_reference``
======================================================

.. automodule:: psyclone.psyir.nodes.array_of_structures_reference

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.array_of_structures_reference


Classes
=======

- :py:class:`ArrayOfStructuresReference`:
  Node representing an access to a member of one or more elements of an


.. autoclass:: ArrayOfStructuresReference
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayOfStructuresReference
      :parts: 1
